// Hello, World! application. Copyright (C) 1996-1998 Santa Fe Institute.
// This library is distributed without any warranty; without even the
// implied warranty of merchantability or fitness for a particular purpose.
// See file LICENSE for details and terms of copying.

// Ppl main.m: this particular "simulation" starts with a soup of people
// with randomly generated names who run around saying "Hello" to anyone
// else in the soup over and over again.

#import "PplObserverSwarm.h"

int
main (int argc, const char **argv)
{
  PplObserverSwarm *observerSwarm;

  initSwarm (argc, argv);

  observerSwarm = [PplObserverSwarm create: globalZone];
  [observerSwarm buildObjects];
  [observerSwarm buildActions];
  [observerSwarm activateIn: nil];
  [observerSwarm go];

  return 0;
}
